@@ -1,4 +1,4 @@
-import csv
+import csv, sys
 from collections import namedtuple
 
 import twobitreader as tbr
@@ -27,7 +27,13 @@ def get_context_twobit_window(mutations, twobit_file, window_size):
     contexts = {}
 
     fname = twobit_file if twobit_file.endswith('.2bit') else twobit_file + '.2bit'
-    f = tbr.TwoBitFile(fname)
+
+    try:
+        f = tbr.TwoBitFile(fname)
+    except FileNotFoundError as fnf_error:
+        sys.exit(f'The 2bit genome assembly file, {fname}, was not found!')
+    except Exception as e:
+        sys.exit(f'An error occurred while reading the 2bit genome assembly file, {fname}!')
 
     cn = complementary_nucleotide
     for (chrom, pos, transcript_strand, x, y) in mutations:
@@ -194,6 +200,12 @@ def read_TCGI_with_context_window(infile, asm, window_size):
     return mutations, mutations_with_context, processing_stats
 
 
+def read_mutations(file_format, *args, **kwargs):
+    """ Wrapper for read_X_with_context_window """
+    function_name = "read_{}_with_context_window".format(file_format)
+    return globals()[function_name](*args, **kwargs)
+
+
 def read_MAF_with_context_window(infile, asm, window_size):
     """
         Read MAF file and extract context of mutations for assembly asm and window +/- window_size around each mutation
@@ -270,11 +282,6 @@ def read_MAF_with_context_window(infile, asm, window_size):
             raise ValueError('Start position is not defined in MAF file')
 
         # assuming that reference strand for reported mutations is always '+'!
-        if hasattr(data, 'strand'):
-            if data.strand != '+' and data.strand != '1':
-                raise ValueError('Mutations should be reported on the "+" reference strand')
-        else:
-            raise ValueError('Reference strand is not specified')
 
         # transcript strand could be anything
         if hasattr(data, 'transcript_strand'):
@@ -332,6 +339,7 @@ def read_MAF_with_context_window(infile, asm, window_size):
         'nsamples': len(mutations.keys()),
         'format': 'MAF'
     }
+
     return mutations, mutations_with_context, processing_stats
 
 
